/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.fleet;

import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.util.logging.Level;
import java.util.logging.Logger;
import nl.cloudfarming.client.fleet.model.Fleet;
import nl.cloudfarming.client.fleet.model.FleetManager;
import org.netbeans.api.project.Project;
import org.netbeans.api.project.ProjectManager;
import org.netbeans.spi.project.ui.support.DefaultProjectOperations;
import org.openide.filesystems.FileObject;
import org.openide.filesystems.FileUtil;
import org.openide.util.Exceptions;
import org.openide.util.lookup.ServiceProvider;

/**
 *
 * @author Wytse Visser & Maciek Dulkiewicz
 */
@ServiceProvider(service = FleetManager.class)
public class FleetManagerImpl implements FleetManager {
    
    private static final Logger LOGGER = Logger.getLogger("nl.cloudfarming.client.fleet");

    @Override
    public Fleet load(FileObject fileObject) {
        Fleet fleet = null;
        try (ObjectInputStream ois = new ObjectInputStream(fileObject.getInputStream())) {
            fleet = (Fleet) ois.readObject();
        } catch (ClassNotFoundException | IOException ex) {
            LOGGER.log(Level.WARNING, "Could not load fleet from file", ex.getMessage());
        }
        return fleet;
    }

    @Override
    public void save(Fleet fleet, FileObject fileObject) {
        try (ObjectOutputStream oos = new ObjectOutputStream(fileObject.getOutputStream())) {
            oos.writeObject(fleet);
        } catch (IOException ex) {
            Exceptions.printStackTrace(ex);
        }
        
        // renaming project folder if fleet name changed
        try {
            FileObject projectDir = fileObject.getParent();

            if (!projectDir.getName().equals(fleet.getName())) {
                String actualNewName = FileUtil.findFreeFolderName(projectDir.getParent(), fleet.getName());
                Project project = ProjectManager.getDefault().findProject(projectDir);
                DefaultProjectOperations.performDefaultRenameOperation(project, actualNewName);
            }
        } catch (IOException ex) {
            Exceptions.printStackTrace(ex);
        }
    }
}
