/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.fleet.wizard;

import java.awt.Component;
import java.util.HashSet;
import java.util.Set;
import javax.swing.ImageIcon;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;
import nl.cloudfarming.client.util.swing.ASBodyPanel;
import org.openide.WizardDescriptor;
import org.openide.util.HelpCtx;
import org.openide.util.ImageUtilities;
import org.openide.util.NbBundle;

/**
 *
 * @author Wytse Visser
 */
class FleetWizardNamePanel implements WizardDescriptor.Panel {

    private WizardDescriptor wizardDescriptor;
    private FleetWizardNameVisual bodyPanel;
    private ASBodyPanel component;
    private ImageIcon icon = ImageUtilities.loadImageIcon("nl/cloudfarming/client/fleet/fleet32.png", false);
    private final Set<ChangeListener> listeners = new HashSet<>(1); // or can use ChangeSupport in NB 6.0    

    @Override
    public Component getComponent() {
        if (bodyPanel == null) {
            bodyPanel = new FleetWizardNameVisual(this);
            component = new ASBodyPanel(bodyPanel);
            component.setName(NbBundle.getMessage(FleetWizardNamePanel.class, "LBL_CreateProjectStep"));
            component.setIcon(icon);
        }
        return component;
    }

    @Override
    public HelpCtx getHelp() {
        return null;
    }

    @Override
    public void readSettings(Object settings) {
        wizardDescriptor = (WizardDescriptor) settings;
        bodyPanel.read(wizardDescriptor);
    }

    @Override
    public void storeSettings(Object settings) {
        WizardDescriptor d = (WizardDescriptor) settings;
        bodyPanel.store(d);
    }

    @Override
    public boolean isValid() {
        return bodyPanel.valid(wizardDescriptor);
    }

    @Override
    public final void addChangeListener(ChangeListener l) {
        synchronized (listeners) {
            listeners.add(l);
        }
    }

    @Override
    public final void removeChangeListener(ChangeListener l) {
        synchronized (listeners) {
            listeners.remove(l);
        }
    }

    protected final void fireChangeEvent() {
        Set<ChangeListener> ls;
        synchronized (listeners) {
            ls = new HashSet<>(listeners);
        }
        ChangeEvent ev = new ChangeEvent(this);
        for (ChangeListener l : ls) {
            l.stateChanged(ev);
        }
    }
}
